# SaveTube ![Python application](https://github.com/bawaviki/SaveTube/workflows/Python%20application/badge.svg)
[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/) [![GitHub stars](https://img.shields.io/github/stars/bawaviki/SaveTube)](https://github.com/bawaviki/SaveTube/stargazers) [![GitHub forks](https://img.shields.io/github/forks/bawaviki/SaveTube?color=red)](https://github.com/bawaviki/SaveTube/network) [![Twitter](https://img.shields.io/twitter/url?style=social&url=https%3A%2F%2Fbawaviki.github.io%2FSaveTube%2F)](https://twitter.com/intent/tweet?text=Wow:&url=https%3A%2F%2Fgithub.com%2Fbawaviki%2FSaveTube%2F)

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Savetube?color=yellow) ![PyPI](https://img.shields.io/pypi/v/SaveTube?color=orange) [![GitHub license](https://img.shields.io/github/license/bawaviki/SaveTube)](https://github.com/bawaviki/SaveTube/blob/master/LICENSE) [![Downloads](https://pepy.tech/badge/savetube/month)](https://pepy.tech/project/savetube/month) [![GitHub issues](https://img.shields.io/github/issues/bawaviki/SaveTube?color=%235E6BB8)](https://github.com/bawaviki/SaveTube/issues)

A **cross platform** front-end **GUI** as well as simple **CLI** of the popular [youtube-dl](https://rg3.github.io/youtube-dl/) media downloader written in tkinter. [Supported sites](https://rg3.github.io/youtube-dl/supportedsites.html)

- [REQIREMENTS](#Requirements)
- [DOWNLOADS](Downloads)
- [INSTALLATION](#Installation)
- [DESCRIPTION](#Description)
- [OPTIONS](#Options)
- [SCREENSHOTS](#Screenshots)
- [SUPPORT](#Support)

## Requirements
* [Python 3.+](https://www.python.org/downloads)
* [FFmpeg](https://ffmpeg.org/download.html) (optional, to post process video files)

## Downloads
* [Source (.zip)](https://github.com/bawaviki/SaveTube/archive/1.1.zip)
* [Source (.tar.gz)](https://github.com/bawaviki/SaveTube/archive/1.1.tar.gz)
* [PyPi](https://pypi.python.org/pypi/Savetube/)
* [Windows Installer](https://github.com/bawaviki/SaveTube/releases/download/1.1/savetube-win-setup.exe)
* [Windows Portable](https://github.com/bawaviki/SaveTube/releases/download/1.1/savetube-win-portable.zip)


# Installation

* ### Install From Source
1. Download & extract the source
2. Change directory into *Savetube-1.1*
3. Run `python setup.py install`

* ### Install PyPi
1. Run `pip install savetube`

* ### Install Windows Installer
1. Download & extract the Windows installer
2. Run the `setup.exe` file

# DESCRIPTION
 > **savetube** is a command-line as well as GUI program to download videos from YouTube.com and a few more sites. It requires [youtube-dl](https://rg3.github.io/youtube-dl/) and the Python interpreter, version 3.2+, also it is not platform specific. It should work on your Unix box, on Windows or on macOS.

          savetube [OPTIONS]  URL 

# OPTIONS
* ## For CLI
```shell
     -h,     --help           Print this help text and exit.
     -v,     --version        Print program version and exit.
     -U,     --url            Provide the url to progam to work.
```      
* ## For GUI

    *__Just type savetube and hit enter. A small window will apear, paste url and see the magic.__*
```bash
        $ savetube
```

# Screenshots
* ## GUI
![youtube-dl-gui main window](https://github.com/bawaviki/static-files/raw/master/savetube_py_gui.gif)

* ## CLI
![youtube-dl-gui main window](https://github.com/bawaviki/static-files/raw/master/savetube_py_cli.gif)

# Support
If you like my work and **want to support** me use **sponsor button above** or click any **option bellow**. Or you also suppot me **by give star to project**. If you want to contribute **feel free to fork**.


[![BuyMeACofee](https://img.shields.io/static/v1?label=Support&message=Bring%20Me%20A%20Cofee&color=FF813F)](https://www.buymeacoffee.com/bawaviki)      [![Paytm](https://img.shields.io/static/v1?label=Support&message=Paytm&color=002E6E)](https://p-y.tm/27-ydgU) [![PayPal](https://img.shields.io/static/v1?label=Support&message=PayPal&color=00457C)](https://paypal.me/bawaviki)   [![PayPal](https://img.shields.io/static/v1?label=Support&message=Patreon&color=f96854)](https://patreon.com/bawaviki)
